@@ -5,13 +5,13 @@ CLI arguments definition.
 from argparse import (FileType, OPTIONAL, SUPPRESS, ZERO_OR_MORE)
 from textwrap import dedent, wrap
 
-from httpie import __doc__, __version__
-from httpie.cli.argparser import HTTPieArgumentParser
-from httpie.cli.argtypes import (
+from .. import __doc__, __version__
+from .argparser import HTTPieArgumentParser
+from .argtypes import (
     KeyValueArgType, SessionNameValidator,
-    readable_file_arg,
+    readable_file_arg, response_charset_type, response_mime_type,
 )
-from httpie.cli.constants import (
+from .constants import (
     DEFAULT_FORMAT_OPTIONS, OUTPUT_OPTIONS,
     OUTPUT_OPTIONS_DEFAULT, OUT_REQ_BODY, OUT_REQ_HEAD,
     OUT_RESP_BODY, OUT_RESP_HEAD, PRETTY_MAP, PRETTY_STDOUT_TTY_ONLY,
@@ -19,25 +19,25 @@ from httpie.cli.constants import (
     SORTED_FORMAT_OPTIONS_STRING,
     UNSORTED_FORMAT_OPTIONS_STRING,
 )
-from httpie.output.formatters.colors import (
+from ..output.formatters.colors import (
     AUTO_STYLE, AVAILABLE_STYLES, DEFAULT_STYLE,
 )
-from httpie.plugins.builtin import BuiltinAuthPlugin
-from httpie.plugins.registry import plugin_manager
-from httpie.sessions import DEFAULT_SESSIONS_DIR
-from httpie.ssl import AVAILABLE_SSL_VERSION_ARG_MAPPING, DEFAULT_SSL_CIPHERS
+from ..plugins.builtin import BuiltinAuthPlugin
+from ..plugins.registry import plugin_manager
+from ..sessions import DEFAULT_SESSIONS_DIR
+from ..ssl import AVAILABLE_SSL_VERSION_ARG_MAPPING, DEFAULT_SSL_CIPHERS
 
 
 parser = HTTPieArgumentParser(
     prog='http',
-    description='%s <https://httpie.org>' % __doc__.strip(),
+    description=f'{__doc__.strip()} <https://httpie.io>',
     epilog=dedent('''
     For every --OPTION there is also a --no-OPTION that reverts OPTION
     to its default value.
 
     Suggestions and bug reports are greatly appreciated:
 
-        https://github.com/jakubroztocil/httpie/issues
+        https://github.com/httpie/httpie/issues
 
     '''),
 )
@@ -96,7 +96,7 @@ positional.add_argument(
 
     ':' HTTP headers:
 
-        Referer:http://httpie.org  Cookie:foo=bar  User-Agent:bacon/1.0
+        Referer:https://httpie.io  Cookie:foo=bar  User-Agent:bacon/1.0
 
     '==' URL parameters to be appended to the request URI:
 
@@ -185,6 +185,25 @@ content_type.add_argument(
 
     '''
 )
+content_type.add_argument(
+    '--raw',
+    help='''
+    This option allows you to pass raw request data without extra processing
+    (as opposed to the structured request items syntax):
+
+        $ http --raw='data' pie.dev/post
+
+    You can achieve the same by piping the data via stdin:
+
+        $ echo data | http pie.dev/post
+
+    Or have HTTPie load the raw data from a file:
+
+        $ http pie.dev/post @data.txt
+
+
+    '''
+)
 
 
 #######################################################################
@@ -233,11 +252,11 @@ output_processing.add_argument(
     dest='style',
     metavar='STYLE',
     default=DEFAULT_STYLE,
-    choices=AVAILABLE_STYLES,
+    choices=sorted(AVAILABLE_STYLES),
     help='''
     Output coloring style (default is "{default}"). It can be One of:
 
-    {available_styles}
+        {available_styles}
 
     The "{auto_style}" style follows your terminal's ANSI color styles.
 
@@ -248,7 +267,7 @@ output_processing.add_argument(
     '''.format(
         default=DEFAULT_STYLE,
         available_styles='\n'.join(
-            '{0}{1}'.format(8 * ' ', line.strip())
+            f'        {line.strip()}'
             for line in wrap(', '.join(sorted(AVAILABLE_STYLES)), 60)
         ).strip(),
         auto_style=AUTO_STYLE,
@@ -290,6 +309,31 @@ output_processing.add_argument(
     '''
 )
 
+output_processing.add_argument(
+    '--response-charset',
+    metavar='ENCODING',
+    type=response_charset_type,
+    help='''
+    Override the response encoding for terminal display purposes, e.g.:
+
+        --response-charset=utf8
+        --response-charset=big5
+
+    '''
+)
+
+output_processing.add_argument(
+    '--response-mime',
+    metavar='MIME_TYPE',
+    type=response_mime_type,
+    help='''
+    Override the response mime type for coloring and formatting for the terminal, e.g.:
+
+        --response-mime=application/json
+        --response-mime=text/xml
+
+    '''
+)
 
 output_processing.add_argument(
     '--format-options',
@@ -311,7 +355,7 @@ output_processing.add_argument(
 
     '''.format(
         option_list='\n'.join(
-            (8 * ' ') + option for option in DEFAULT_FORMAT_OPTIONS).strip()
+            f'        {option}' for option in DEFAULT_FORMAT_OPTIONS).strip()
     )
 )
 
@@ -364,12 +408,12 @@ output_options.add_argument(
     '--verbose', '-v',
     dest='verbose',
     action='store_true',
-    help='''
+    help=f'''
     Verbose output. Print the whole request as well as the response. Also print
     any intermediary requests/responses (such as redirects).
-    It's a shortcut for: --all --print={0}
+    It's a shortcut for: --all --print={''.join(OUTPUT_OPTIONS)}
 
-    '''.format(''.join(OUTPUT_OPTIONS))
+    '''
 )
 output_options.add_argument(
     '--all',
@@ -453,12 +497,14 @@ output_options.add_argument(
 
 output_options.add_argument(
     '--quiet', '-q',
-    action='store_true',
-    default=False,
+    action='count',
+    default=0,
     help='''
-    Do not print to stdout or stderr.
+    Do not print to stdout or stderr, except for errors and warnings when provided once.
+    Provide twice to suppress warnings as well.
     stdout is still redirected if --output is specified.
     Flag doesn't affect behaviour of download beyond not printing to terminal.
+
     '''
 )
 
@@ -543,7 +589,7 @@ auth.add_argument(
             name=plugin.name,
             package=(
                 '' if issubclass(plugin, BuiltinAuthPlugin)
-                else ' (provided by %s)' % plugin.package_name
+                else f' (provided by {plugin.package_name})'
             ),
             description=(
                 '' if not plugin.description else
@@ -667,9 +713,11 @@ network.add_argument(
     '--chunked',
     default=False,
     action='store_true',
-    help="""
+    help='''
+    Enable streaming via chunked transfer encoding.
+    The Transfer-Encoding header is set to chunked.
 
-    """
+    '''
 )
 
 #######################################################################
@@ -690,7 +738,7 @@ ssl.add_argument(
 ssl.add_argument(
     '--ssl',
     dest='ssl_version',
-    choices=list(sorted(AVAILABLE_SSL_VERSION_ARG_MAPPING.keys())),
+    choices=sorted(AVAILABLE_SSL_VERSION_ARG_MAPPING.keys()),
     help='''
     The desired protocol version to use. This will default to
     SSL v2.3 which will negotiate the highest protocol that both
