@@ -2,7 +2,7 @@ from base64 import b64encode
 
 import requests.auth
 
-from httpie.plugins.base import AuthPlugin
+from .base import AuthPlugin
 
 
 # noinspection PyAbstractClass
@@ -19,23 +19,25 @@ class HTTPBasicAuth(requests.auth.HTTPBasicAuth):
         """
         Override username/password serialization to allow unicode.
 
-        See https://github.com/jakubroztocil/httpie/issues/212
+        See https://github.com/httpie/httpie/issues/212
 
         """
+        # noinspection PyTypeChecker
         request.headers['Authorization'] = type(self).make_header(
             self.username, self.password).encode('latin1')
         return request
 
     @staticmethod
     def make_header(username: str, password: str) -> str:
-        credentials = u'%s:%s' % (username, password)
-        token = b64encode(credentials.encode('utf8')).strip().decode('latin1')
-        return 'Basic %s' % token
+        credentials = f'{username}:{password}'
+        token = b64encode(credentials.encode()).strip().decode('latin1')
+        return f'Basic {token}'
 
 
 class BasicAuthPlugin(BuiltinAuthPlugin):
     name = 'Basic HTTP auth'
     auth_type = 'basic'
+    netrc_parse = True
 
     # noinspection PyMethodOverriding
     def get_auth(self, username: str, password: str) -> HTTPBasicAuth:
@@ -43,9 +45,9 @@ class BasicAuthPlugin(BuiltinAuthPlugin):
 
 
 class DigestAuthPlugin(BuiltinAuthPlugin):
-
     name = 'Digest HTTP auth'
     auth_type = 'digest'
+    netrc_parse = True
 
     # noinspection PyMethodOverriding
     def get_auth(
