@@ -13,9 +13,9 @@ from urllib.parse import urlsplit
 from requests.auth import AuthBase
 from requests.cookies import RequestsCookieJar, create_cookie
 
-from httpie.cli.dicts import RequestHeadersDict
-from httpie.config import BaseConfigDict, DEFAULT_CONFIG_DIR
-from httpie.plugins.registry import plugin_manager
+from .cli.dicts import RequestHeadersDict
+from .config import BaseConfigDict, DEFAULT_CONFIG_DIR
+from .plugins.registry import plugin_manager
 
 
 SESSIONS_DIR_NAME = 'sessions'
@@ -52,7 +52,7 @@ def get_httpie_session(
 
 
 class Session(BaseConfigDict):
-    helpurl = 'https://httpie.org/doc#sessions'
+    helpurl = 'https://httpie.io/docs#sessions'
     about = 'HTTPie session file'
 
     def __init__(self, path: Union[str, Path]):
@@ -72,13 +72,13 @@ class Session(BaseConfigDict):
 
         """
         headers = self.headers
-        for name, value in request_headers.items():
+        for name, value in request_headers.copy().items():
 
             if value is None:
                 continue  # Ignore explicitly unset headers
 
             if type(value) is not str:
-                value = value.decode('utf8')
+                value = value.decode()
 
             if name.lower() == 'user-agent' and value.startswith('HTTPie/'):
                 continue
@@ -112,7 +112,7 @@ class Session(BaseConfigDict):
 
     @cookies.setter
     def cookies(self, jar: RequestsCookieJar):
-        # <https://docs.python.org/2/library/cookielib.html#cookie-objects>
+        # <https://docs.python.org/3/library/cookielib.html#cookie-objects>
         stored_attrs = ['value', 'path', 'secure', 'expires']
         self['cookies'] = {}
         for cookie in jar:
@@ -141,7 +141,7 @@ class Session(BaseConfigDict):
             }
         else:
             if plugin.auth_parse:
-                from httpie.cli.argtypes import parse_auth
+                from .cli.argtypes import parse_auth
                 parsed = parse_auth(plugin.raw_auth)
                 credentials = {
                     'username': parsed.key,
